Struct bevy_capture::encoder::gif::GifEncoder
source · pub struct GifEncoder<W: Write>(/* private fields */);Expand description
An encoder that encodes a sequence of images into a gif.
Implementations
sourceimpl<W: Write> GifEncoder<W>
impl<W: Write> GifEncoder<W>
sourcepub fn new(writer: W) -> Self
pub fn new(writer: W) -> Self
Creates a new gif encoder that writes the gif to the given writer, e.g. a file.
sourcepub fn new_with_speed(writer: W, speed: i32) -> Self
pub fn new_with_speed(writer: W, speed: i32) -> Self
Creates a new gif encoder that writes the gif to the given writer, e.g. a file,
with the given speed.
See Frame::from_rgba_speed
for more information on the speed parameter.
sourcepub fn with_repeat(self, repeat: Repeat) -> Self
pub fn with_repeat(self, repeat: Repeat) -> Self
Sets the repeat mode of the gif.